@@ -33,7 +33,13 @@ public:
   Report(const Report& src);
   Report& operator=(const Report& src);
 
+  bool get_show_table_title() const;
+  void set_show_table_title(bool show_table_title = true);
+
   sharedptr<LayoutGroup> m_layout_group;
+
+protected:
+  bool m_show_table_title;
 };
 
 #endif //GLOM_DATASTRUCTURE_REPORT_H
