@@ -48,7 +48,7 @@ public:
 
   bool get_name_not_empty() const; //For performance.
 
-  virtual Glib::ustring TranslatableItem::get_title_or_name() const;
+  virtual Glib::ustring get_title_or_name() const;
 
   /** Get the title's translation for the current locale.
    */
@@ -91,7 +91,9 @@ public:
      TRANSLATABLE_TYPE_CUSTOM_TITLE,
      TRANSLATABLE_TYPE_REPORT,
      TRANSLATABLE_TYPE_TABLE,
-     TRANSLATABLE_TYPE_BUTTON
+     TRANSLATABLE_TYPE_BUTTON,
+     TRANSLATABLE_TYPE_TEXTOBJECT,
+     TRANSLATABLE_TYPE_IMAGEOBJECT
    };
 
   enumTranslatableItemType get_translatable_item_type();
