@@ -35,6 +35,7 @@
 #include "../data_structure/groupinfo.h"
 #include "../data_structure/report.h"
 #include "../appstate.h"
+#include <gtkmm/window.h>
 #include <vector>
 #include <map>
 
@@ -162,7 +163,9 @@ public:
   virtual void change_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
 
   typedef std::list< sharedptr<TableInfo> > type_listTableInfo;
-  virtual type_listTableInfo get_tables() const;
+  virtual type_listTableInfo get_tables(bool plus_system_prefs = false) const;
+  std::vector<Glib::ustring> get_table_names(bool plus_system_prefs = false) const;
+
   virtual void set_tables(const type_listTableInfo& tables);
 
   sharedptr<TableInfo> get_table(const Glib::ustring table_name) const;
@@ -244,7 +247,11 @@ public:
 
   virtual void emit_userlevel_changed();
 
+  void set_parent_window(Gtk::Window* window);
+
+  static sharedptr<TableInfo> create_table_system_preferences();
   static sharedptr<TableInfo> create_table_system_preferences(type_vecFields& fields);
+  static sharedptr<Relationship>  create_relationship_system_preferences(const Glib::ustring& table_name);
   static bool get_relationship_is_system_properties(const sharedptr<const Relationship>& relationship);
 
   static void set_node_attribute_value_as_decimal(xmlpp::Element* node, const Glib::ustring& strAttributeName, int value);
@@ -289,8 +296,6 @@ protected:
   static void set_node_attribute_value_as_value(xmlpp::Element* node, const Glib::ustring& strAttributeName, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
   static Gnome::Gda::Value get_node_attribute_value_as_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName, Field::glom_field_type field_type);
 
-  static sharedptr<Relationship> create_relationship_system_preferences(const Glib::ustring& table_name);
-
   AppState m_app_state;
   type_signal_userlevel_changed m_signal_userlevel_changed;
 
@@ -350,6 +355,8 @@ protected:
   bool m_block_modified_set;
   bool m_allow_auto_save;
   bool m_is_example;
+
+  Gtk::Window* m_parent_window; //Needed by BusyCursor.(gtype_0)
 };
 
 //The base View for this document;
