@@ -107,13 +107,13 @@ public:
   bool connection_request_password_and_attempt();
 
   //Show the dialog to request the password, and choose an unused database name.
-  bool Frame_Glom::connection_request_password_and_choose_new_database_name();
+  bool connection_request_password_and_choose_new_database_name();
 
   ///Create the database for new documents, showing the Connection dialog
   bool create_database(const Glib::ustring& database_name, const Glib::ustring& title, bool request_password = true);
 
-  void export_data_to_string(Glib::ustring& the_string, const Glib::ustring table_name, const Document_Glom::type_mapLayoutGroupSequence& sequence, const Glib::ustring& where_clause = Glib::ustring());
-  void export_data_to_stream(std::ostream& the_stream, const Glib::ustring table_name, const Document_Glom::type_mapLayoutGroupSequence& sequence, const Glib::ustring& where_clause = Glib::ustring());
+  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence);
+  void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence);
 
   /** Show the table again. For instance, if the document has changed, or we want to display it differently.
    */
