@@ -133,15 +133,15 @@ Gnome::Gda::Value Box_Data_Details::get_primary_key_value() const
   return m_primary_key_value;
 }
 
-bool Box_Data_Details::init_db_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value)
+bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value)
 {
   //std::cout << "Box_Data_Details::init_db_details(): primary_key_value.to_string()=" << primary_key_value.to_string() << std::endl;
 
   m_primary_key_value = primary_key_value;
 
-  m_field_primary_key = get_field_primary_key_for_table(table_name);
+  m_field_primary_key = get_field_primary_key_for_table(found_set.m_table_name);
 
-  return Box_Data::init_db_details(table_name); //Calls create_layout(), then fill_from_database()
+  return Box_Data::init_db_details(found_set); //Calls create_layout(), then fill_from_database()
 }
 
 bool Box_Data_Details::refresh_data_from_database_with_primary_key(const Gnome::Gda::Value& primary_key_value)
@@ -158,7 +158,7 @@ bool Box_Data_Details::refresh_data_from_database_blank()
 
 void Box_Data_Details::create_layout()
 {
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   Box_Data::create_layout(); //Fills m_TableFields.
 
@@ -187,7 +187,7 @@ bool Box_Data_Details::fill_from_database()
 
   bool bResult = false;
 
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   const bool primary_key_is_empty = GlomConversions::value_is_empty(m_primary_key_value);
   if(!primary_key_is_empty)
@@ -198,7 +198,7 @@ bool Box_Data_Details::fill_from_database()
 
     //TODO: This should keep the connection open, so we don't need to 
     //reconnect many times..
-    sharedptr<SharedConnection> sharedconnection = connect_to_server();
+    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
 
 
     bResult = Box_Data::fill_from_database();
@@ -229,7 +229,7 @@ bool Box_Data_Details::fill_from_database()
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
-          result = Query_execute(query);
+          result = Query_execute(query, get_app_window());
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
@@ -604,7 +604,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     try
     {
       FieldInRecord field_in_record(layout_field, m_table_name /* parent table */, primary_key_field, primary_key_value, *(get_document()));
-      const bool bTest = set_field_value_in_database(field_in_record, field_value);
+      const bool bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
 
       //Glib::ustring strQuery = "UPDATE \"" + table_name + "\"";
       //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
