@@ -95,20 +95,23 @@ void Box_Data_List::enable_buttons()
 
 void Box_Data_List::refresh_data_from_database_blank()
 {
-  m_AddDel.set_where_clause(Glib::ustring());
+  FoundSet found_set = m_found_set;
+  found_set.m_where_clause = Glib::ustring();
+  m_AddDel.set_found_set(found_set);
+
   m_AddDel.refresh_from_database_blank();
-  m_where_clause = Glib::ustring();
+  m_found_set = found_set;
 }
 
 bool Box_Data_List::fill_from_database()
 {
   bool result = false;
 
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   try
   {
-    sharedptr<SharedConnection> sharedconnection = connect_to_server();
+    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
 
     Box_Data::fill_from_database();
 
@@ -126,7 +129,7 @@ bool Box_Data_List::fill_from_database()
 
     enable_buttons();
 
-    m_AddDel.set_where_clause(m_where_clause);
+    m_AddDel.set_found_set(m_found_set);
 
     result = m_AddDel.refresh_from_database();
 
@@ -255,7 +258,7 @@ void Box_Data_List::on_adddel_user_added(const Gtk::TreeModel::iterator& row, gu
   //If no primary key value is available yet, then don't add the record yet:
   if(!GlomConversions::value_is_empty(primary_key_value))
   {
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(); //Keep it alive while we need the data_model.
+    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window()); //Keep it alive while we need the data_model.
     if(sharedconnection)
     {
       Glib::RefPtr<Gnome::Gda::DataModel> data_model = record_new(true /* use entered field data*/, primary_key_value);
@@ -385,7 +388,7 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
       //const Glib::ustring strFieldName = layout_field->get_name();
 
       FieldInRecord field_in_record(layout_field, m_table_name /* parent */, primary_key_field, primary_key_value, *(get_document()));
-      const bool bTest = set_field_value_in_database(field_in_record, row, field_value);
+      const bool bTest = set_field_value_in_database(field_in_record, row, field_value, false /* don't use current calculations */, get_app_window());
 
       //Glib::ustring strQuery = "UPDATE \"" + table_name + "\"";
       //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
@@ -625,7 +628,7 @@ void Box_Data_List::create_layout()
         m_AddDel.add_column(field);
       }
 
-      m_AddDel.set_where_clause(m_where_clause);
+      m_AddDel.set_found_set(m_found_set);
 
       m_AddDel.set_columns_ready();
      }
@@ -701,7 +704,7 @@ void Box_Data_List::print_layout()
       report_temp->m_layout_group->add_item(*iter);
     }
 
-    report_build(m_table_name, report_temp, m_where_clause);
+    report_build(m_found_set, report_temp, get_app_window());
   }
 }
 
