@@ -84,13 +84,8 @@ Box_Data_List_Related::~Box_Data_List_Related()
 
 void Box_Data_List_Related::enable_buttons()
 {
-  bool to_table_is_hidden = false;
-  if(m_portal->get_has_relationship_name())
-  {
-    to_table_is_hidden = get_document()->get_table_is_hidden(m_portal->get_relationship()->get_to_table());
-  }
-
-  m_AddDel.set_allow_view_details(!to_table_is_hidden); //Don't allow the user to go to a record in a hidden table.
+  const bool view_details_possible = get_has_suitable_record_to_view_details();
+  m_AddDel.set_allow_view_details(view_details_possible); //Don't allow the user to go to a record in a hidden table.
 }
 
 bool Box_Data_List_Related::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
@@ -125,7 +120,9 @@ bool Box_Data_List_Related::init_db_details(const sharedptr<const LayoutItem_Por
 
   if(relationship)
   {
-    return Box_Data_List::init_db_details(relationship->get_to_table()); //Calls create_layout() and fill_from_database().
+    FoundSet found_set;
+    found_set.m_table_name = relationship->get_to_table();
+    return Box_Data_List::init_db_details(found_set); //Calls create_layout() and fill_from_database().
   }
   else
     return false;
@@ -139,10 +136,11 @@ bool Box_Data_List_Related::refresh_data_from_database_with_foreign_key(const Gn
   {
     if(!GlomConversions::value_is_empty(m_key_value))
     {
-      const Glib::ustring where_clause = "\"" + m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
+      FoundSet found_set = m_found_set;
+      found_set.m_where_clause = "\"" + m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
 
       //g_warning("refresh_data_from_database(): where_clause=%s", where_clause.c_str());
-      return Box_Data_List::refresh_data_from_database_with_where_clause(where_clause);
+      return Box_Data_List::refresh_data_from_database_with_where_clause(found_set);
     }
     else
     {
@@ -154,7 +152,9 @@ bool Box_Data_List_Related::refresh_data_from_database_with_foreign_key(const Gn
   else
   {
     //If there is no to field then this relationship specifies all relationships in the table.
-    return Box_Data_List::refresh_data_from_database_with_where_clause(Glib::ustring());
+    FoundSet found_set = m_found_set;
+    found_set.m_where_clause = Glib::ustring();
+    return Box_Data_List::refresh_data_from_database_with_where_clause(found_set);
   }
 }
 
@@ -163,7 +163,7 @@ bool Box_Data_List_Related::fill_from_database()
   bool result = false;
   bool allow_add = true;
 
-  if(m_key_field && m_where_clause.empty()) //There's a key field, but no value.
+  if(m_key_field && m_found_set.m_where_clause.empty()) //There's a key field, but no value.
   {
     //No Foreign Key value, so just show the field names:
 
@@ -243,7 +243,7 @@ void Box_Data_List_Related::on_record_added(const Gnome::Gda::Value& primary_key
         Glib::ustring strQuery = "UPDATE \"" + m_portal->get_relationship()->get_to_table() + "\"";
         strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
         strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value);
-        bool test = Query_execute(strQuery);
+        bool test = Query_execute(strQuery, get_app_window());
         if(test)
         {
           //Show it on the view, if it's visible:
@@ -278,6 +278,12 @@ void Box_Data_List_Related::on_record_deleted(const Gnome::Gda::Value& /* primar
 
 void Box_Data_List_Related::on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col)
 {
+  if(!(get_relationship()->get_allow_edit()))
+  {
+    std::cerr << "Box_Data_List_Related::on_adddel_user_added() called on non-editable portal. This should not happen." << std::endl;
+   return;
+  }
+
   //Call base class:
   Box_Data_List::on_adddel_user_changed(row, col);
 
@@ -288,6 +294,13 @@ void Box_Data_List_Related::on_adddel_user_changed(const Gtk::TreeModel::iterato
 
 void Box_Data_List_Related::on_adddel_user_added(const Gtk::TreeModel::iterator& row, guint col_with_first_value)
 {
+  sharedptr<const Relationship> relationship = get_relationship();
+  if(!relationship->get_allow_edit())
+  {
+    std::cerr << "Box_Data_List_Related::on_adddel_user_added() called on non-editable portal. This should not happen." << std::endl;
+   return;
+  }
+
   //Like Box_Data_List::on_adddel_user_added(),
   //but it doesn't allow adding if the new record cannot be a related record.
   //This would happen if there is already one related record and the relationship uses the primary key in the related record.
@@ -328,7 +341,20 @@ Box_Data_List_Related::type_vecLayoutFields Box_Data_List_Related::get_fields_to
     sharedptr<const Relationship> relationship = m_portal->get_relationship();
     if(relationship)
     {
-      return get_table_fields_to_show_for_sequence(relationship->get_to_table(), mapGroups);
+      type_vecLayoutFields result = get_table_fields_to_show_for_sequence(relationship->get_to_table(), mapGroups);
+
+      //If the relationship does not allow editing, then mark all these fields as non-editable:
+      if(!(get_relationship()->get_allow_edit()))
+      {
+        for(type_vecLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
+        {
+          sharedptr<LayoutItem_Field> item = *iter;
+          if(item)
+            item->set_editable(false);
+        }
+      }
+
+      return result;
     }
   }
 
@@ -374,3 +400,151 @@ void Box_Data_List_Related::on_adddel_user_requested_add()
   if(!m_portal->m_map_items.empty())
     Box_Data_List::on_adddel_user_requested_add();
 }
+
+sharedptr<const LayoutItem_Field> Box_Data_List_Related::get_field_identifies_non_hidden_related_record() const
+{
+  //Find the first field that is from a non-hidden related table.
+  sharedptr<LayoutItem_Field> result;
+
+  const Document_Glom* document = get_document();
+  if(!document)
+    return result;
+
+  for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+  {
+    sharedptr<const LayoutItem_Field> field = *iter;
+    if(field && !(field->get_has_relationship_name()))
+    {
+      sharedptr<Relationship> relationship = document->get_field_used_in_relationship_to_one(LayoutWidgetBase::m_table_name, field->get_name());
+      if(relationship)
+      {
+        const Glib::ustring table_name = relationship->get_to_table();
+        if(!(table_name.empty()))
+        {
+          if(!(document->get_table_is_hidden(table_name)))
+            return field;
+        }
+      }
+    }
+  }
+
+  return result;
+}
+
+sharedptr<const LayoutItem_Field> Box_Data_List_Related::get_field_is_from_non_hidden_related_record() const
+{
+  //Find the first field that is from a non-hidden related table.
+  sharedptr<LayoutItem_Field> result;
+
+  const Document_Glom* document = get_document();
+  if(!document)
+    return result;
+
+  for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+  {
+    sharedptr<const LayoutItem_Field> field = *iter;
+    if(field)
+    {
+      if(field->get_has_relationship_name())
+      {
+        const Glib::ustring table_name = field->get_table_used(LayoutWidgetBase::m_table_name);
+        if(!(document->get_table_is_hidden(table_name)))
+          return field;
+      }
+
+    }
+  }
+
+  return result;
+}
+
+bool Box_Data_List_Related::get_has_suitable_record_to_view_details() const
+{
+  const Document_Glom* document = get_document();
+  if(!document)
+    return false;
+
+  if(!(document->get_table_is_hidden(LayoutWidgetBase::m_table_name)))
+  {
+    return true;
+  }
+  else
+  {
+    //Find a suitable related table by finding the first layout field that mentions one:
+    sharedptr<const LayoutItem_Field> field = get_field_is_from_non_hidden_related_record();
+    if(field)
+      return true;
+    else
+    {
+      sharedptr<const LayoutItem_Field> field = get_field_identifies_non_hidden_related_record();
+      if(field)
+       return true;
+    }
+  }
+
+  return false;
+}
+
+void Box_Data_List_Related::get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value)
+{
+  //Initialize output parameters:
+  table_name = Glib::ustring();
+  table_primary_key_value = Gnome::Gda::Value();
+
+  const Document_Glom* document = get_document();
+  if(!document)
+    return;
+
+  if(!(document->get_table_is_hidden(LayoutWidgetBase::m_table_name)))
+  {
+    table_name = LayoutWidgetBase::m_table_name;
+    table_primary_key_value = primary_key_value;
+  }
+  else
+  {
+    //Find a suitable related table by finding the first layout field that mentions one:
+    sharedptr<const LayoutItem_Field> field = get_field_is_from_non_hidden_related_record();
+    if(field)
+    {
+      table_name = field->get_table_used(LayoutWidgetBase::m_table_name);
+
+      sharedptr<Field> related_primary_key = get_field_primary_key_for_table(table_name);
+      if(related_primary_key)
+      {
+        //Get the value of the related primary key:
+        sharedptr<LayoutItem_Field> layout_item = glom_sharedptr_clone(field); //To keep the relationship info.
+        layout_item->set_name(related_primary_key->get_name());
+        layout_item->set_full_field_details(related_primary_key);
+
+        type_vecLayoutFields fieldsToGet;
+        fieldsToGet.push_back(layout_item);
+
+        //std::cout << "PRIMARY_KEY_TABLE=" << LayoutWidgetBase::m_table_name << std::endl;
+        //std::cout << "PRIMARY_KEY_TABLE_TO=" << m_portal->get_relationship()->get_to_table() << std::endl;
+        //std::cout << "PRIMARY_KEY_VALUE=" << primary_key_value.to_string() << std::endl;
+
+        const Glib::ustring query = GlomUtils::build_sql_select_with_key(LayoutWidgetBase::m_table_name, fieldsToGet, m_AddDel.get_key_field(), primary_key_value);
+        Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(query);
+        if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
+        {
+          table_primary_key_value = data_model->get_value_at(0, 0);
+          //std::cout << "Box_Data_List_Related::get_suitable_record_to_view_details(): table_primary_key_value=" << table_primary_key_value.to_string() << std::endl;
+        }
+        else
+        {
+           std::cout << "Box_Data_List_Related::get_suitable_record_to_view_details(): SQL query returned no suitable primary key" << std::endl;
+        }
+      }
+    }
+    else
+    {
+       sharedptr<const LayoutItem_Field> field = get_field_identifies_non_hidden_related_record();
+       if(field)
+       {
+         //TODO: We need the relationship, and we need to worry about doubly-related fields.
+         //table_name = field->get_table_used();
+       }
+    }
+
+  }
+}
