@@ -26,9 +26,14 @@ Dialog_ChooseField::Dialog_ChooseField(BaseObjectType* cobject, const Glib::RefP
 : Gtk::Dialog(cobject),
   m_combo_relationship(0),
   m_button_select(0),
+  m_checkbutton_show_related_relationships(0),
   m_treeview(0),
   m_document(0)
 {
+  refGlade->get_widget("checkbutton_show_related_relationships", m_checkbutton_show_related_relationships);
+  m_checkbutton_show_related_relationships->set_active(false); //Start with the simpler list, to avoid confusing people.
+  m_checkbutton_show_related_relationships->signal_toggled().connect(sigc::mem_fun(*this, &Dialog_ChooseField::on_checkbutton_related_relationships_toggled));
+
   refGlade->get_widget("button_select", m_button_select);
   refGlade->get_widget_derived("combobox_relationship", m_combo_relationship);
   m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_ChooseField::on_combo_relationship_changed));
@@ -60,36 +65,44 @@ Dialog_ChooseField::~Dialog_ChooseField()
 {
 }
 
-void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustring& table_name,  const LayoutItem_Field& field)
+void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field)
 {
   set_document(document, table_name);
 
   //Select the current relationship at the start:
-
-  if(field.get_has_relationship_name())
+  if(field && field->get_has_relationship_name())
   {
-    m_combo_relationship->set_active_text( field.get_relationship_name() );
+    if(field->get_has_related_relationship_name())
+      m_checkbutton_show_related_relationships->set_active(true); //We'll need the full list of relationships to show this.
+
+    m_combo_relationship->set_selected_relationship( field->get_relationship(), field->get_related_relationship());
   }
   else
-    m_combo_relationship->set_active_text(table_name);
+    m_combo_relationship->set_selected_parent_table(table_name, document->get_table_title(table_name)); 
 
   //Select the current field at the start:
-  const Glib::ustring field_name = field.get_name();
-
-  //Get the iterator for the row:
-  Gtk::TreeModel::iterator iterFound = m_model->children().end();
-  for(Gtk::TreeModel::iterator iter = m_model->children().begin(); iter != m_model->children().end(); ++iter)
+  if(field)
   {
-    if(field_name == (*iter)[m_ColumnsFields.m_col_name])
+    const Glib::ustring field_name = field->get_name();
+
+    //Get the iterator for the row:
+    Gtk::TreeModel::iterator iterFound = m_model->children().end();
+    for(Gtk::TreeModel::iterator iter = m_model->children().begin(); iter != m_model->children().end(); ++iter)
     {
-      iterFound = iter;
-      break;
+      if(field_name == (*iter)[m_ColumnsFields.m_col_name])
+      {
+        iterFound = iter;
+        break;
+      }
     }
-  }
 
-  if(iterFound != m_model->children().end())
-  {
-    m_treeview->get_selection()->select(iterFound);
+    if(iterFound != m_model->children().end())
+    {
+      m_treeview->get_selection()->select(iterFound);
+
+      //Make sure that it is scrolled into view:
+      m_treeview->scroll_to_row(Gtk::TreeModel::Path(iterFound));
+    }
   }
 }
 
@@ -112,23 +125,16 @@ void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustri
   if(document)
   {
     //Fill the list of relationships:
-    m_combo_relationship->clear_text();
-    Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(table_name);
 
     //Add a special option for the current table:
-    m_combo_relationship->append_text(table_name);
+    m_combo_relationship->set_display_parent_table(table_name, document->get_table_title(table_name));
 
     //Add the relationships for this table:
-    if(!vecRelationships.empty())
-      m_combo_relationship->append_separator();
-
-    for(Document_Glom::type_vecRelationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
-    {
-      m_combo_relationship->append_text(iter->get_name());
-    }
+    const Glib::ustring table_title = document->get_table_title(table_name);
+    m_combo_relationship->set_relationships(document, table_name, false /* show related relationships */);
 
     //Set the table name and title:
-    m_combo_relationship->set_active_text(table_name);
+    m_combo_relationship->set_selected_parent_table(table_name, table_title);
 
     //Fill the treeview:
     m_model->clear();
@@ -137,9 +143,11 @@ void Dialog_ChooseField::set_document(Document_Glom* document, const Glib::ustri
     {
       Gtk::TreeModel::iterator iterRow = m_model->append();
       Gtk::TreeModel::Row row = *iterRow;
-      row[m_ColumnsFields.m_col_name] = iter->get_name();
-      row[m_ColumnsFields.m_col_title] = iter->get_title();
-      row[m_ColumnsFields.m_col_field] = *iter;
+
+      sharedptr<Field> field = *iter;
+      row[m_ColumnsFields.m_col_name] = field->get_name();
+      row[m_ColumnsFields.m_col_title] = field->get_title();
+      row[m_ColumnsFields.m_col_field] = field;
     }
   }
 }
@@ -165,24 +173,13 @@ void Dialog_ChooseField::select_item(const Field& field)
 }
 */
 
-bool Dialog_ChooseField::get_field_chosen(LayoutItem_Field& field) const
+sharedptr<LayoutItem_Field> Dialog_ChooseField::get_field_chosen() const
 {
   //Don't initialize output argument,
   //because it might contain other useful data.
   //TODO: Store a LayoutItem_Field as a member.
 
-
-  //Relationship:
-  Glib::ustring relationship_name = m_combo_relationship->get_active_text();
-  if(relationship_name == m_table_name)
-    relationship_name.clear();
-
-  //field.set_relationship_name(relationship_name);
-
-  if(!relationship_name.empty())
-  {
-    m_document->get_relationship(m_table_name, relationship_name, field.m_relationship);
-  }
+  sharedptr<LayoutItem_Field> field;
 
   //Field:
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview->get_selection();
@@ -191,15 +188,27 @@ bool Dialog_ChooseField::get_field_chosen(LayoutItem_Field& field) const
     Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
     if(iter)
     {
-      Gtk::TreeModel::Row row = *iter;
-      field.set_name(row[m_ColumnsFields.m_col_name]);
-      field.m_field = row[m_ColumnsFields.m_col_field];
+      field = sharedptr<LayoutItem_Field>::create(); //TODO_Translation: Preserve existing.
 
-      return true;
+      //Relationship:
+      //Note that a null relationship means that the parent table was selected instead.
+      sharedptr<Relationship> related_relationship;
+      sharedptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(related_relationship);
+
+      //field.set_relationship_name(relationship_name);
+
+      field->set_relationship(relationship);
+      field->set_related_relationship(related_relationship);
+
+
+      Gtk::TreeModel::Row row = *iter;
+      sharedptr<Field> field_details = row[m_ColumnsFields.m_col_field];
+      field->set_full_field_details(field_details);
+      field->set_name(row[m_ColumnsFields.m_col_name]);
     }
   }
 
-  return false;
+  return field;
 }
 
 void Dialog_ChooseField::on_row_activated(const Gtk::TreePath& /* path */, Gtk::TreeViewColumn* /* view_column */)
@@ -207,9 +216,26 @@ void Dialog_ChooseField::on_row_activated(const Gtk::TreePath& /* path */, Gtk::
   response(Gtk::RESPONSE_OK);
 }
 
+void Dialog_ChooseField::on_checkbutton_related_relationships_toggled()
+{
+  if(!m_document)
+    return;
+
+  const bool show_related_relationships = m_checkbutton_show_related_relationships->get_active();
+
+  //Preserve the selection:
+  sharedptr<Relationship> related_relationship;
+  sharedptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(related_relationship);
+
+  //Refresh the list, hiding or showing the child relationships:
+  m_combo_relationship->set_relationships(m_document, m_table_name, show_related_relationships);
+
+  m_combo_relationship->set_selected_relationship(relationship, related_relationship);
+}
+
 void Dialog_ChooseField::on_combo_relationship_changed()
 {
-  Glib::ustring relationship_name = m_combo_relationship->get_active_text();
+  sharedptr<Relationship> relationship = m_combo_relationship->get_selected_relationship();
 
   Document_Glom* pDocument = m_document;
   if(pDocument)
@@ -217,14 +243,11 @@ void Dialog_ChooseField::on_combo_relationship_changed()
     //Show the list of fields from this relationship:
 
     Document_Glom::type_vecFields vecFields;
-    if(relationship_name == m_table_name)
+    if(!relationship)
       vecFields = pDocument->get_table_fields(m_table_name);
     else
     {
-      Relationship relationship;
-      pDocument->get_relationship(m_table_name, relationship_name, relationship);
-
-      vecFields = pDocument->get_table_fields(relationship.get_to_table());
+      vecFields = pDocument->get_table_fields(relationship->get_to_table());
     }
 
     m_model->clear();
@@ -232,9 +255,11 @@ void Dialog_ChooseField::on_combo_relationship_changed()
     {
       Gtk::TreeModel::iterator iterRow = m_model->append();
       Gtk::TreeModel::Row row = *iterRow;
-      row[m_ColumnsFields.m_col_name] = iter->get_name();
-      row[m_ColumnsFields.m_col_title] = iter->get_title();
-      row[m_ColumnsFields.m_col_field] = *iter;
+
+      sharedptr<Field> field = *iter;
+      row[m_ColumnsFields.m_col_name] = field->get_name();
+      row[m_ColumnsFields.m_col_title] = field->get_title();
+      row[m_ColumnsFields.m_col_field] = field;
     }
 
   }
