@@ -156,7 +156,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
   Glib::ustring name = m_AddDel.get_value(row, m_colName);
   if(!name.empty())
   {
-    bool bTest = Query_execute( "ALTER TABLE \"" + m_table_name + "\" ADD \"" + name + "\" NUMERIC" ); //TODO: Get schema type for Field::TYPE_NUMERIC
+    bool bTest = Query_execute( "ALTER TABLE \"" + m_table_name + "\" ADD \"" + name + "\" NUMERIC", get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
     if(bTest)
     {
       //Show the new field (fill in the other cells):
@@ -196,7 +196,7 @@ void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& r
     Glib::ustring name = m_AddDel.get_value_key(iter);
     if(!name.empty())
     {
-      Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" + name + "\"");
+      Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" + name + "\"", get_app_window());
 
       //Remove it from all layouts, reports, etc:
       get_document()->remove_field(m_table_name, name);
@@ -376,7 +376,7 @@ void Box_DB_Table_Definition::on_Properties_apply()
 
 void Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fieldOld, const sharedptr<const Field>& field)
 {
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   //DB field defintion:
 
@@ -441,19 +441,6 @@ void Box_DB_Table_Definition::fill_fields()
   m_vecFields = get_fields_for_table(m_table_name);
 }
 
-void  Box_DB_Table_Definition::postgres_add_column(const sharedptr<const Field>& field, bool not_extras)
-{
-  const bool bTest = Query_execute(  "ALTER TABLE \"" + m_table_name + "\" ADD \"" + field->get_name() + "\" " +  field->get_sql_type() );
-  if(bTest)
-  {
-    if(not_extras)
-    {
-      //We must do this separately:
-      postgres_change_column_extras(field, field, true /* set them even though the fields are the same */);
-    }
-  }
-}
-
 void  Box_DB_Table_Definition::postgres_change_column(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field)
 {
   const Gnome::Gda::FieldAttributes field_info = field->get_field_info();
@@ -467,13 +454,14 @@ void  Box_DB_Table_Definition::postgres_change_column(const sharedptr<const Fiel
   else
   {
     //Change other stuff, without changing the type:
-    postgres_change_column_extras(field_old, field);
+    postgres_change_column_extras(m_table_name, field_old, field);
   }
 }
 
+
 void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field)
 {
-  sharedptr<SharedConnection> sharedconnection = connect_to_server();
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
   if(sharedconnection)
   {
     Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
@@ -500,7 +488,7 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
 
         sharedptr<Field> fieldTemp = glom_sharedptr_clone(field);
         fieldTemp->set_name("glom_temp_column");
-        postgres_add_column(fieldTemp); //This might also involves several commands.
+        postgres_add_column(m_table_name, fieldTemp); //This might also involves several commands.
 
 
         bool conversion_failed = false;
@@ -584,20 +572,20 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
             }
           }
 
-          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "UPDATE \"" + m_table_name + "\" SET \"" + fieldTemp->get_name() + "\" = " + conversion_command );  //TODO: Not full type details.
+          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "UPDATE \"" + m_table_name + "\" SET \"" + fieldTemp->get_name() + "\" = " + conversion_command, get_app_window());  //TODO: Not full type details.
           if(!datamodel)
             conversion_failed = true;
         }
 
         if(!conversion_failed)
         {
-          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" +  field_old->get_name() + "\"");
+          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" +  field_old->get_name() + "\"", get_app_window());
           if(datamodel)
           {
-            datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN \"" + fieldTemp->get_name() + "\" TO \"" + field->get_name() + "\"");
+            datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN \"" + fieldTemp->get_name() + "\" TO \"" + field->get_name() + "\"", get_app_window());
             if(datamodel)
             {
-              bool test = gda_connection->commit_transaction(transaction);
+              const bool test = gda_connection->commit_transaction(transaction);
               if(!test)
               {
                 handle_error();
@@ -611,88 +599,10 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
     }  /// If the datatype has changed:
 
     if(!new_column_created) //We don't need to change anything else if everything was alrady correctly set as a new column:
-      postgres_change_column_extras(field_old, field);
+      postgres_change_column_extras(m_table_name, field_old, field);
   }
 }
 
 
-void Box_DB_Table_Definition::postgres_change_column_extras(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, bool set_anyway)
-{
-  //Gnome::Gda::FieldAttributes field_info = field->get_field_info();
-  //Gnome::Gda::FieldAttributes field_info_old = field_old->get_field_info();
-
-  if(field->get_name() != field_old->get_name())
-  {
-     Glib::RefPtr<Gnome::Gda::DataModel>  datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN \"" + field_old->get_name() + "\" TO \"" + field->get_name() + "\"" );
-     if(!datamodel)
-     {
-       handle_error();
-       return;
-     }
-  }
-
-  if(set_anyway || (field->get_primary_key() != field_old->get_primary_key()))
-  {
-    //TODO: Check that there is only one primary key.
-    Glib::ustring add_or_drop = "ADD";
-    if(field_old->get_primary_key() == false)
-      add_or_drop = "DROP";
-
-    Glib::RefPtr<Gnome::Gda::DataModel>  datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" " + add_or_drop + " PRIMARY KEY (\"" + field->get_name() + "\")");
-    if(!datamodel)
-    {
-      handle_error();
-      return;
-    }
-  }
-
-  if( !field->get_primary_key() ) //Postgres automatically makes primary keys unique, so we do not need to do that separately if we have already made it a primary key
-  {
-    if(set_anyway || (field->get_unique_key() != field_old->get_unique_key()))
-    {
-       /* TODO: Is there an easier way than adding an index manually?
-       Glib::RefPtr<Gnome::Gda::DataModel>  datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN " + field_info_old.get_name() + " TO " + field_info.get_name() );
-       if(!datamodel)
-       {
-         handle_error();
-         return;
-       }
-       */
-    }
-
-    Gnome::Gda::Value default_value = field->get_default_value();
-    Gnome::Gda::Value default_value_old = field_old->get_default_value();
-
-    if(!field->get_auto_increment()) //Postgres auto-increment fields have special code as their default values.
-    {
-      if(set_anyway || (default_value != default_value_old))
-      {
-        Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" ALTER COLUMN \""+ field->get_name() + "\" SET DEFAULT " + field->sql(field->get_default_value()) );
-        if(!datamodel)
-        {
-          handle_error();
-          return;
-        }
-      }
-    }
-  }
-
-  /* This should have been dealt with by postgres_change_column_type(), because postgres uses a different ("serial") field type for auto-incrementing fields.
-  if(field_info.get_auto_increment() != field_info_old.get_auto_increment())
-  {
-
-  }
-  */
- 
-   /*
-    //If the not-nullness has changed:
-    if( set_anyway ||  (field->get_field_info().get_allow_null() != field_old->get_field_info().get_allow_null()) )
-    {
-      Glib::ustring nullness = (field->get_field_info().get_allow_null() ? "NULL" : "NOT NULL");
-      Query_execute(  "ALTER TABLE " + m_table_name + " ALTER COLUMN " + field->get_name() + "  SET " + nullness);
-    }
-  */ 
-}
-
 
 
