@@ -22,6 +22,7 @@
 #include "dialog_user.h"
 #include "dialog_users_list.h"
 #include "dialog_new_group.h"
+#include "../../standard_table_prefs_fields.h"
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
@@ -45,7 +46,6 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   m_model_groups = Gtk::ListStore::create(m_model_columns_groups);
   m_model_tables = Gtk::ListStore::create(m_model_columns_tables);
 
-
   fill_group_list();
   //fill_table_list();
 
@@ -62,10 +62,9 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
 
   m_treeview_groups->append_column(_("Description"), m_model_columns_groups.m_col_description);
 
-
-
   //Tables:
-  m_treeview_tables->append_column(_("Table"), m_model_columns_tables.m_col_name);
+  m_treeview_tables->append_column(_("Table"), m_model_columns_tables.m_col_title);
+
 
   treeview_append_bool_column(*m_treeview_tables, _("View"), m_model_columns_tables.m_col_view,
     sigc::mem_fun( *this, &Dialog_GroupsList::on_treeview_tables_toggled_view) );
@@ -92,8 +91,6 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
     refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_treeview_tables_selection_changed) );
   }
 
-
-
   refGlade->get_widget("button_group_new", m_button_group_new);
   m_button_group_new->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_button_group_new) );
 
@@ -103,7 +100,6 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   refGlade->get_widget("button_group_users", m_button_group_users);
   m_button_group_users->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_button_group_users) );
 
-
   enable_buttons();
 
   show_all_children();
@@ -179,6 +175,9 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
 
 void Dialog_GroupsList::enable_buttons()
 {
+  if(!m_button_group_users)
+    return;
+
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
@@ -222,7 +221,7 @@ void Dialog_GroupsList::on_button_group_delete()
         if(response == Gtk::RESPONSE_OK)
         {
           Glib::ustring strQuery = "DROP GROUP " + user;
-          Query_execute(strQuery);
+          Query_execute(strQuery, this);
 
           fill_group_list();
         }
@@ -260,20 +259,23 @@ void Dialog_GroupsList::on_button_group_new()
   if(!group_name.empty())
   {
     Glib::ustring strQuery = "CREATE GROUP " + group_name;
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery);
+    Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery, this);
 
     //Give the new group some sensible default privileges:
     Privileges priv;
     priv.m_view = true;
     priv.m_edit = true;
 
-    Document_Glom::type_listTableInfo table_list = get_document()->get_tables();
+    Document_Glom::type_listTableInfo table_list = get_document()->get_tables(true /* plus system prefs */);
 
     for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
       set_table_privileges(group_name, (*iter)->get_name(), priv);
     }
 
+    //Let them edit the autoincrements too:
+    set_table_privileges(group_name, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv);
+
     fill_group_list();
   }
 }
@@ -374,14 +376,17 @@ void Dialog_GroupsList::fill_group_list()
       row[m_model_columns_groups.m_col_description] = _("Full access.");
   }
 
-  //Select the first item, so that there is always something in the tables TreeView:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
-  if(refSelection)
+  if(m_treeview_groups && m_treeview_groups->get_model()) //Avoid a warning.
   {
-    Gtk::TreeModel::iterator iterFirst = m_model_groups->children().begin();
-    if(iterFirst)
+    //Select the first item, so that there is always something in the tables TreeView:
+    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
+    if(refSelection)
     {
-      refSelection->select(iterFirst);
+      Gtk::TreeModel::iterator iterFirst = m_model_groups->children().begin();
+      if(iterFirst)
+      {
+        refSelection->select(iterFirst);
+      }
     }
   }
 }
@@ -399,7 +404,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
      GroupInfo group_info;
      group_info.set_name(group_name);
 
-    Document_Glom::type_listTableInfo table_list = pDocument->get_tables();
+    Document_Glom::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
 
     for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
@@ -409,6 +414,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
       const Glib::ustring table_name = (*iter)->get_name();
 
       row[m_model_columns_tables.m_col_name] = table_name;
+      row[m_model_columns_tables.m_col_title] = (*iter)->get_title_or_name();
 
       const Privileges privs = get_table_privileges(group_name, table_name);
       row[m_model_columns_tables.m_col_view] = privs.m_view;
@@ -478,7 +484,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
   else if(priv == PRIV_DELETE)
     strPrivilege = "DELETE";
 
-  strQuery += " " + strPrivilege + " ON " + table_name + " ";
+  strQuery += " " + strPrivilege + " ON \"" + table_name + "\" ";
 
   //This must match the Grant or Revoke:
   if(grant)
@@ -486,9 +492,9 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
   else
     strQuery += "FROM";
 
-  strQuery += " GROUP " + group_name;
+  strQuery += " GROUP \"" + group_name + "\"";
 
-  Query_execute(strQuery); //TODO: Handle errors.
+  Query_execute(strQuery, this); //TODO: Handle errors.
 
   return true;
 }
