@@ -40,12 +40,14 @@ Box_Data_Details_Find::~Box_Data_Details_Find()
 
 bool Box_Data_Details_Find::init_db_details(const Glib::ustring& table_name)
 {
-  return Box_Data_Details::init_db_details(table_name, Gnome::Gda::Value());
+  FoundSet found_set;
+  found_set.m_table_name = table_name;
+  return Box_Data_Details::init_db_details(found_set, Gnome::Gda::Value());
 }
 
 bool Box_Data_Details_Find::fill_from_database()
 {
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   bool result = Box_DB_Table::fill_from_database();
 
@@ -62,7 +64,7 @@ void Box_Data_Details_Find::fill_related()
   //m_Notebook_Related.pages().clear();
 
   //Get relationships from the document:
-  Document_Glom::type_vecRelationships vecRelationships = get_document()->get_relationships(m_strTableName);
+  Document_Glom::type_vecRelationships vecRelationships = get_document()->get_relationships(m_table_name);
 
   //Add the relationships:
   for(Document_Glom::type_vecRelationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); iter++)
