@@ -29,14 +29,19 @@ public:
   Box_Data_List_Find();
   virtual ~Box_Data_List_Find();
 
+  virtual bool init_db_details(const Glib::ustring& table_name);
+
   virtual Gtk::Widget* get_default_button(); //override
-    
+
 protected:
 
-  virtual void fill_from_database(); //override.
+  virtual bool fill_from_database(); //override.
+  virtual void create_layout();
+
+  virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col); //override
+  virtual void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& /* rowStart */, const Gtk::TreeModel::iterator&  /* rowEnd TODO */);
+  virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& /* row */, guint /* col_with_first_value */);
 
-  virtual void on_AddDel_user_changed(const Gtk::TreeModel::iterator& row, guint col); //override
-  
   //Member widgets:
   Gtk::HBox m_HBox;
 };
