@@ -20,6 +20,7 @@
 
 #include "datawidget.h"
 #include "entryglom.h"
+#include "labelglom.h"
 #include "comboentryglom.h"
 #include "comboglom.h"
 #include "textviewglom.h"
@@ -234,14 +235,19 @@ void DataWidget::set_value(const Gnome::Gda::Value& value)
   Gtk::Widget* widget = get_data_child_widget();
   LayoutWidgetField* generic_field_widget = dynamic_cast<LayoutWidgetField*>(widget);
   if(generic_field_widget)
+  {
+    //if(generic_field_widget->get_layout_item())
+    //  std::cout << "DataWidget::set_value(): generic_field_widget->get_layout_item()->get_name()=" << generic_field_widget->get_layout_item()->get_name() << std::endl;
+
     generic_field_widget->set_value(value);
+  }
   else
   {
     Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(widget);
     if(checkbutton)
     {
       bool bValue = false;
-      if(!value.is_null())
+      if(!value.is_null() && value.get_value_type() == Gnome::Gda::VALUE_TYPE_BOOLEAN)
         bValue = value.get_bool();
 
       checkbutton->set_active( bValue );
@@ -361,18 +367,14 @@ void DataWidget::set_editable(bool editable)
     entry->set_editable(editable);
   else
   {
-    Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(child);
-    if(checkbutton)
-      checkbutton->set_sensitive(editable);
+    LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(child);
+    if(base)
+      base->set_read_only(!editable);
     else
     {
-      Gtk::ComboBoxEntry* comboboxentry = dynamic_cast<Gtk::ComboBoxEntry*>(child);
-      if(comboboxentry)
-      {
-        Gtk::Entry* entry = comboboxentry->get_entry();
-        if(entry)
-          entry->set_editable(editable);
-      }
+      Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(child);
+      if(checkbutton)
+        checkbutton->set_sensitive(editable);
     }
   }
 }
@@ -638,12 +640,12 @@ const Gtk::Widget* DataWidget::get_data_child_widget() const
  {
    return m_signal_open_details_requested;
  }
- 
+
  void DataWidget::on_button_open_details()
  {
    signal_open_details_requested().emit(get_value());
  }
- 
+
  void DataWidget::on_button_select_id()
  {
    Gnome::Gda::Value chosen_id;
