@@ -80,7 +80,7 @@ void TextViewGlom::check_for_change()
     //Validate the input:
     bool success = false;
 
-    const LayoutItem_Field* layout_item = dynamic_cast<const LayoutItem_Field*>(get_layout_item());
+    sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
     Gnome::Gda::Value value = GlomConversions::parse_value(m_glom_type, new_text, layout_item->get_formatting_used().m_numeric_format, success);
 
     if(success)
@@ -143,7 +143,7 @@ void TextViewGlom::on_insert_text(const Glib::ustring& text, int* position)
 
 void TextViewGlom::set_value(const Gnome::Gda::Value& value)
 {
-  const LayoutItem_Field* layout_item = dynamic_cast<const LayoutItem_Field*>(get_layout_item());
+  sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
   if(layout_item)
     set_text(GlomConversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format));
 }
@@ -160,7 +160,7 @@ Gnome::Gda::Value TextViewGlom::get_value() const
 {
   bool success = false;
 
-  const LayoutItem_Field* layout_item = dynamic_cast<const LayoutItem_Field*>(get_layout_item());
+  sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
 
   TextViewGlom* pNonConstThis = const_cast<TextViewGlom*>(this); //Gtk::TextBuffer::get_text() is non-const in gtkmm <=2.6.
   return GlomConversions::parse_value(m_glom_type, pNonConstThis->m_TextView.get_buffer()->get_text(true), layout_item->get_formatting_used().m_numeric_format, success);
